summaryrefslogtreecommitdiffstats
path: root/kdat/IndexDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/IndexDlg.h')
-rw-r--r--kdat/IndexDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/IndexDlg.h b/kdat/IndexDlg.h
index 9dfd6ea..ffbc505 100644
--- a/kdat/IndexDlg.h
+++ b/kdat/IndexDlg.h
@@ -79,10 +79,10 @@ public:
* Create a new tape index dialog.
*
* @param tape A pointer to the empty tape index to fill in.
* @param tqparent The tqparent widget for this dialog.
* @param name The name of this dialog.
*/
- IndexDlg( Tape* tape, TQWidget* tqparent = 0, const char* name = 0 );
+ IndexDlg( Tape* tape, TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the tape index dialog.
@@ -79,10 +79,10 @@ public:
*
* @param tape A pointer to the empty tape index to fill in.
- * @param tqparent The tqparent widget for this dialog.
+ * @param parent The parent widget for this dialog.
* @param name The name of this dialog.
*/